#!/bin/sh

# This variable is the program used to install files and directories.
# Normally it is "cp -pr", but it could also be "mv".
install="cp -pr"

# This variable is the program used to create symbolic links.  If your
# operating system doesn't support symbolic links, you might want to
# change this to "ln" or "cp -p".
link="ln -s"

# This variable specifies the directory that will contain the Scheme
# executable programs.
bindir="/usr/local/bin"

# This variable specifies the directory that will contain the
# auxiliary files required by Scheme:
libdir="/usr/local/lib/mit-scheme"

# This variable says whether or not to delete the files "compdel.com"
# and "eddel.com" after they have been used to create the
# "compiler.com" and "edwin.com" files.  If you want to keep these
# files, change "yes" to "no" here.
deletedeltas="yes"

# This variable specifies the directory where GNU Emacs "Info" files
# are stored.  The script looks for an Info directory file in some
# standard places, and uses one of those places if found.

infodir=""
if [ -f /usr/local/info/dir ]
then
  infodir=/usr/local/info
elif [ -f /usr/info/dir ]
then
  infodir=/usr/info
fi

# This variable specifies where the GNU Emacs "xscheme.el" program
# should be installed.  This program is used to run Scheme as a
# subprocess under GNU Emacs.  An older version of this program is
# distributed with GNU Emacs, but you should always use the version
# distributed with Scheme.  The script looks for an appropriate
# directory in some standard places.

emacslisp=""
if [ -d /usr/local/lib/emacs/site-lisp ]
then
  emacslisp="/usr/local/lib/emacs/site-lisp"
fi

# This variable specifies where the GNU Emacs "movemail" program can
# be found.  This program is used by Edwin for the same purpose,
# namely to fetch mail from the user's mailbox when running RMAIL.
# This script looks for an appropriate executable in some standard
# places.

movemail=""
if [ -d /usr/lib/emacs ]
then
  set -- `ls /usr/lib/emacs | fgrep 19.`
  if [ $# -gt 0 ]
  then
    set -- `ls /usr/lib/emacs/$1/*/movemail`
    if [ $# -gt 0 -a -x $1 ]
    then
      movemail=$1
    fi
  fi
fi

echo "Using the following configuration settings:"
echo ""
echo "Installation program = $install"
echo "(Symbolic) link program = $link"
echo "Directory for executable programs = $bindir"
echo "Directory for library files = $libdir"

if [ "$deletedeltas" = "yes" ]
then
  echo "Delete eddel.com and compdel.com after building bands"
else
  echo "Keep eddel.com and compdel.com after building bands"
fi

if [ "$infodir" = "" ]
then
  echo "No Info directory found"
else
  echo "Info directory = $infodir"
fi

if [ "$emacslisp" = "" ]
then
  echo "Not installing Emacs .el files"
else
  echo "Installing Emacs .el files in $emacslisp"
fi

if [ "$movemail" = "" ]
then
  echo "No movemail program found"
else
  echo "movemail program = $movemail"
fi

echo ""
echo "Type 'yes' if these choices are correct:"
read answer
if [ "$answer" != "yes" ]
then
  echo "Please edit the install.sh script with appropriate values."
  exit
fi

if [ ! -d "${bindir}" ]
then
  mkdir ${bindir}
fi
if [ ! -d "${libdir}" ]
then
  mkdir ${libdir}
fi

if [ -f "${libdir}/compiler.com" ]
then
  rm -f ${libdir}/compiler.com
fi
if [ -f "${libdir}/edwin.com" ]
then
  rm -f ${libdir}/edwin.com
fi
if [ -f "${libdir}/all.com" ]
then
  rm -f ${libdir}/all.com
fi

${install} lib/* ${libdir}/.
if [ "${libdir}" = "/usr/local/lib/mit-scheme" ]
then
  ${install} bin/* ${bindir}/.
else
  (cd bin
   for i in *
   do
     if [ "${i}" = "scheme" -o "${i}" = "bchscheme" ]
     then
       ${install} ${i} ${libdir}/.
       file="${bindir}/${i}"
       rm -f ${file}
       echo "#!/bin/sh" > ${file}
       echo "MITSCHEME_LIBRARY_PATH=${libdir}" >> ${file}
       echo "export MITSCHEME_LIBRARY_PATH" >> ${file}
       echo "exec ${libdir}/$i \$@" >> ${file}
       chmod 755 ${file}
     else
       ${install} ${i} ${bindir}/.
     fi
   done)
fi

if [ "${emacslisp}" != "" ]
then
  ${install} etc/xscheme.el etc/xscheme.elc ${emacslisp}/.
fi

if [ ! -d ${libdir}/edwin/info ]
then
  if [ "${infodir}" != "" ]
  then
    ${link} ${infodir} ${libdir}/edwin/info
  fi
fi

if [ ! -x ${libdir}/edwin/etc/movemail ]
then
  if [ "${movemail}" != "" ]
  then
    ${link} ${movemail} ${libdir}/edwin/etc/movemail
  fi
fi

if [ ! -f "${libdir}/compiler.com" ]
then
  ${bindir}/scheme -large -no-init-file -load etc/mkcomp.scm
fi

if [ ! -f "${libdir}/edwin.com" ]
then
  ${bindir}/scheme -large -no-init-file -load etc/mkedwin.scm
fi

if [ ! -f "${libdir}/all.com" ]
then
  ${bindir}/scheme -large -no-init-file -constant 1600 -load etc/mkall.scm
fi

if [ "${deletedeltas}" = "yes" ]
then
  rm -f ${libdir}/compdel.com ${libdir}/eddel.com
fi
